@@ -401,10 +401,10 @@ bmdd.R <- function(W, type = c('count', 'proportion'),
 
   if(type == 'count') {
     res <- list(gamma = gam, beta = beta, alpha = alp, pi = pi,
-                para.alpha = para.alp, para.pi = para.pi)
+                para.alpha = para.alp, para.pi = para.pi, iter = iter)
   } else {
     res <- list(gamma = gam, alpha = alp, pi = pi,
-                para.alpha = para.alp, para.pi = para.pi)
+                para.alpha = para.alp, para.pi = para.pi, iter = iter)
   }
   return(res)
 }
